@@ -60,8 +60,8 @@ ALLOWED_TAGS = [('request', Namespace.RECEIPTS),
 
 
 class PGPLegacy(BaseModule):
-    def __init__(self, con):
-        BaseModule.__init__(self, con, plugin=True)
+    def __init__(self, client):
+        BaseModule.__init__(self, client, plugin=True)
 
         self.handlers = [
             StanzaHandler(name='message',
@@ -74,7 +74,7 @@ class PGPLegacy(BaseModule):
                           priority=48),
         ]
 
-        self.own_jid = self._con.get_own_jid()
+        self.own_jid = self._client.get_own_jid()
 
         self._pgp = PGP()
         self._store = KeyStore(self._account, self.own_jid, self._log,
@@ -157,7 +157,7 @@ class PGPLegacy(BaseModule):
             callback(event)
             return
 
-        to_jid = app.get_jid_without_resource(event.jid)
+        to_jid = event.jid.bare
         try:
             key_id, own_key_id = self._get_key_ids(to_jid)
         except NoKeyIdFound as error:
