@@ -19,16 +19,14 @@ import logging
 from functools import partial
 from packaging.version import Version as V
 
-import nbxmpp
-
 from gajim.common import app
 from gajim.common import ged
 from gajim.plugins import GajimPlugin
 from gajim.plugins.plugins_i18n import _
 
-from gajim.gui.dialogs import ErrorDialog
-from gajim.gui.dialogs import DialogButton
-from gajim.gui.dialogs import ConfirmationCheckDialog
+from gajim.gtk.dialogs import ErrorDialog
+from gajim.gtk.dialogs import DialogButton
+from gajim.gtk.dialogs import ConfirmationCheckDialog
 
 from pgp.gtk.key import KeyDialog
 from pgp.gtk.config import PGPConfigDialog
@@ -107,7 +105,7 @@ class PGPPlugin(GajimPlugin):
 
     @staticmethod
     def get_pgp_module(account):
-        return app.connections[account].get_module('PGPLegacy')
+        return app.get_client(account).get_module('PGPLegacy')
 
     def activate(self):
         pass
@@ -127,7 +125,7 @@ class PGPPlugin(GajimPlugin):
     def _on_encryption_dialog(self, chat_control):
         account = chat_control.account
         jid = chat_control.contact.jid
-        transient = chat_control.parent_win.window
+        transient = app.window
         KeyDialog(self, account, jid, transient)
 
     def _on_send_presence(self, account, presence):
@@ -155,9 +153,9 @@ class PGPPlugin(GajimPlugin):
         account = chat_control.account
         jid = chat_control.contact.jid
 
-        con = app.connections[account]
+        client = app.get_client(account)
         try:
-            valid = con.get_module('PGPLegacy').has_valid_key_assigned(jid)
+            valid = client.get_module('PGPLegacy').has_valid_key_assigned(jid)
         except KeyMismatch as announced_key_id:
             ErrorDialog(
                 _('PGP Key mismatch'),
@@ -171,7 +169,7 @@ class PGPPlugin(GajimPlugin):
                 _('No OpenPGP key assigned'),
                 _('No OpenPGP key is assigned to this contact.'))
             chat_control.sendmessage = False
-        elif con.get_module('PGPLegacy').get_own_key_data() is None:
+        elif client.get_module('PGPLegacy').get_own_key_data() is None:
             ErrorDialog(
                 _('No OpenPGP key assigned'),
                 _('No OpenPGP key is assigned to your account.'))
